// WARNING: Please don't edit this file. It was generated by Python/WinRT v3.2.1

#pragma once

#include "pybase.h"
static_assert(winrt::check_version(PYWINRT_VERSION, "3.2.1"), "Mismatched Py/WinRT headers.");
#include <winrt/Windows.ApplicationModel.Contacts.h>
#include <winrt/Windows.ApplicationModel.DataTransfer.h>
#include <winrt/Windows.ApplicationModel.Search.h>
#include <winrt/Windows.Foundation.h>
#include <winrt/Windows.Foundation.Collections.h>
#include <winrt/Windows.Globalization.h>
#include <winrt/Windows.Media.Capture.h>
#include <winrt/Windows.Media.Casting.h>
#include <winrt/Windows.Media.Core.h>
#include <winrt/Windows.Media.PlayTo.h>
#include <winrt/Windows.Media.Playback.h>
#include <winrt/Windows.Media.Protection.h>
#include <winrt/Windows.Storage.Streams.h>
#include <winrt/Windows.System.h>
#include <winrt/Windows.UI.h>
#include <winrt/Windows.UI.Composition.h>
#include <winrt/Windows.UI.Core.h>
#include <winrt/Windows.UI.Input.Inking.h>
#include <winrt/Windows.UI.Text.h>
#include <winrt/Windows.UI.Xaml.h>
#include <winrt/Windows.UI.Xaml.Automation.h>
#include <winrt/Windows.UI.Xaml.Automation.Peers.h>
#include <winrt/Windows.UI.Xaml.Controls.Primitives.h>
#include <winrt/Windows.UI.Xaml.Data.h>
#include <winrt/Windows.UI.Xaml.Documents.h>
#include <winrt/Windows.UI.Xaml.Input.h>
#include <winrt/Windows.UI.Xaml.Interop.h>
#include <winrt/Windows.UI.Xaml.Media.h>
#include <winrt/Windows.UI.Xaml.Media.Animation.h>
#include <winrt/Windows.UI.Xaml.Navigation.h>
#include <winrt/Windows.Web.h>
#include <winrt/Windows.Web.Http.h>

#include <winrt/Windows.UI.Xaml.Controls.h>

namespace py::proj::Windows::UI::Xaml::Controls
{
}

namespace py
{
    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::AppBarClosedDisplayMode> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::AutoSuggestionBoxTextChangeReason> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::BackgroundSizing> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::CalendarViewDisplayMode> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::CalendarViewSelectionMode> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::CandidateWindowAlignment> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::CharacterCasing> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::ClickMode> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::ColorPickerHsvChannel> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::ColorSpectrumComponents> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::ColorSpectrumShape> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::ComboBoxSelectionChangedTrigger> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::CommandBarDefaultLabelPosition> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::CommandBarDynamicOverflowAction> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::CommandBarLabelPosition> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::CommandBarOverflowButtonVisibility> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::ContentDialogButton> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::ContentDialogPlacement> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::ContentDialogResult> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::ContentLinkChangeKind> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::DisabledFormattingAccelerators> = "I";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::HandwritingPanelPlacementAlignment> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::IncrementalLoadingTrigger> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::InkToolbarButtonFlyoutPlacement> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::InkToolbarFlyoutItemKind> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::InkToolbarInitialControls> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::InkToolbarMenuKind> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::InkToolbarStencilKind> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::InkToolbarToggle> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::InkToolbarTool> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::ItemsUpdatingScrollMode> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::LightDismissOverlayMode> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::ListPickerFlyoutSelectionMode> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::ListViewReorderMode> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::ListViewSelectionMode> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::NavigationViewBackButtonVisible> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::NavigationViewDisplayMode> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::NavigationViewOverflowLabelMode> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::NavigationViewPaneDisplayMode> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::NavigationViewSelectionFollowsFocus> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::NavigationViewShoulderNavigationEnabled> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::Orientation> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::PanelScrollingDirection> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::ParallaxSourceOffsetKind> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::PasswordRevealMode> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::PivotHeaderFocusVisualPlacement> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::PivotSlideInAnimationGroup> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::RefreshPullDirection> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::RefreshVisualizerOrientation> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::RefreshVisualizerState> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::RequiresPointer> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::RichEditClipboardFormat> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::ScrollBarVisibility> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::ScrollIntoViewAlignment> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::ScrollMode> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::SelectionMode> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::SnapPointsType> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::SplitViewDisplayMode> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::SplitViewPanePlacement> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::StretchDirection> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::SwipeBehaviorOnInvoked> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::SwipeMode> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::Symbol> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::TreeViewSelectionMode> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::TwoPaneViewMode> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::TwoPaneViewPriority> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::TwoPaneViewTallModeConfiguration> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::TwoPaneViewWideModeConfiguration> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::VirtualizationMode> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::WebViewExecutionMode> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::WebViewPermissionState> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::WebViewPermissionType> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::ZoomMode> = "i";


    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::AppBarClosedDisplayMode>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.AppBarClosedDisplayMode";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "AppBarClosedDisplayMode";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::AutoSuggestionBoxTextChangeReason>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.AutoSuggestionBoxTextChangeReason";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "AutoSuggestionBoxTextChangeReason";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::BackgroundSizing>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.BackgroundSizing";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "BackgroundSizing";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::CalendarViewDisplayMode>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.CalendarViewDisplayMode";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "CalendarViewDisplayMode";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::CalendarViewSelectionMode>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.CalendarViewSelectionMode";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "CalendarViewSelectionMode";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::CandidateWindowAlignment>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.CandidateWindowAlignment";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "CandidateWindowAlignment";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::CharacterCasing>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.CharacterCasing";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "CharacterCasing";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ClickMode>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ClickMode";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ClickMode";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ColorPickerHsvChannel>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ColorPickerHsvChannel";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ColorPickerHsvChannel";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ColorSpectrumComponents>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ColorSpectrumComponents";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ColorSpectrumComponents";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ColorSpectrumShape>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ColorSpectrumShape";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ColorSpectrumShape";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ComboBoxSelectionChangedTrigger>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ComboBoxSelectionChangedTrigger";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ComboBoxSelectionChangedTrigger";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::CommandBarDefaultLabelPosition>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.CommandBarDefaultLabelPosition";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "CommandBarDefaultLabelPosition";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::CommandBarDynamicOverflowAction>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.CommandBarDynamicOverflowAction";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "CommandBarDynamicOverflowAction";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::CommandBarLabelPosition>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.CommandBarLabelPosition";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "CommandBarLabelPosition";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::CommandBarOverflowButtonVisibility>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.CommandBarOverflowButtonVisibility";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "CommandBarOverflowButtonVisibility";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ContentDialogButton>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ContentDialogButton";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ContentDialogButton";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ContentDialogPlacement>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ContentDialogPlacement";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ContentDialogPlacement";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ContentDialogResult>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ContentDialogResult";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ContentDialogResult";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ContentLinkChangeKind>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ContentLinkChangeKind";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ContentLinkChangeKind";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::DisabledFormattingAccelerators>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.DisabledFormattingAccelerators";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "DisabledFormattingAccelerators";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::HandwritingPanelPlacementAlignment>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.HandwritingPanelPlacementAlignment";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "HandwritingPanelPlacementAlignment";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::IncrementalLoadingTrigger>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.IncrementalLoadingTrigger";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "IncrementalLoadingTrigger";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::InkToolbarButtonFlyoutPlacement>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.InkToolbarButtonFlyoutPlacement";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "InkToolbarButtonFlyoutPlacement";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::InkToolbarFlyoutItemKind>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.InkToolbarFlyoutItemKind";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "InkToolbarFlyoutItemKind";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::InkToolbarInitialControls>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.InkToolbarInitialControls";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "InkToolbarInitialControls";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::InkToolbarMenuKind>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.InkToolbarMenuKind";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "InkToolbarMenuKind";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::InkToolbarStencilKind>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.InkToolbarStencilKind";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "InkToolbarStencilKind";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::InkToolbarToggle>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.InkToolbarToggle";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "InkToolbarToggle";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::InkToolbarTool>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.InkToolbarTool";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "InkToolbarTool";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ItemsUpdatingScrollMode>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ItemsUpdatingScrollMode";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ItemsUpdatingScrollMode";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::LightDismissOverlayMode>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.LightDismissOverlayMode";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "LightDismissOverlayMode";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ListPickerFlyoutSelectionMode>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ListPickerFlyoutSelectionMode";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ListPickerFlyoutSelectionMode";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ListViewReorderMode>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ListViewReorderMode";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ListViewReorderMode";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ListViewSelectionMode>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ListViewSelectionMode";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ListViewSelectionMode";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::NavigationViewBackButtonVisible>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.NavigationViewBackButtonVisible";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "NavigationViewBackButtonVisible";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::NavigationViewDisplayMode>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.NavigationViewDisplayMode";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "NavigationViewDisplayMode";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::NavigationViewOverflowLabelMode>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.NavigationViewOverflowLabelMode";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "NavigationViewOverflowLabelMode";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::NavigationViewPaneDisplayMode>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.NavigationViewPaneDisplayMode";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "NavigationViewPaneDisplayMode";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::NavigationViewSelectionFollowsFocus>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.NavigationViewSelectionFollowsFocus";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "NavigationViewSelectionFollowsFocus";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::NavigationViewShoulderNavigationEnabled>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.NavigationViewShoulderNavigationEnabled";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "NavigationViewShoulderNavigationEnabled";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Orientation>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.Orientation";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "Orientation";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::PanelScrollingDirection>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.PanelScrollingDirection";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "PanelScrollingDirection";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ParallaxSourceOffsetKind>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ParallaxSourceOffsetKind";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ParallaxSourceOffsetKind";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::PasswordRevealMode>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.PasswordRevealMode";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "PasswordRevealMode";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::PivotHeaderFocusVisualPlacement>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.PivotHeaderFocusVisualPlacement";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "PivotHeaderFocusVisualPlacement";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::PivotSlideInAnimationGroup>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.PivotSlideInAnimationGroup";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "PivotSlideInAnimationGroup";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::RefreshPullDirection>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.RefreshPullDirection";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "RefreshPullDirection";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::RefreshVisualizerOrientation>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.RefreshVisualizerOrientation";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "RefreshVisualizerOrientation";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::RefreshVisualizerState>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.RefreshVisualizerState";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "RefreshVisualizerState";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::RequiresPointer>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.RequiresPointer";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "RequiresPointer";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::RichEditClipboardFormat>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.RichEditClipboardFormat";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "RichEditClipboardFormat";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ScrollBarVisibility>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ScrollBarVisibility";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ScrollBarVisibility";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ScrollIntoViewAlignment>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ScrollIntoViewAlignment";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ScrollIntoViewAlignment";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ScrollMode>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ScrollMode";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ScrollMode";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::SelectionMode>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.SelectionMode";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "SelectionMode";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::SnapPointsType>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.SnapPointsType";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "SnapPointsType";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::SplitViewDisplayMode>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.SplitViewDisplayMode";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "SplitViewDisplayMode";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::SplitViewPanePlacement>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.SplitViewPanePlacement";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "SplitViewPanePlacement";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::StretchDirection>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.StretchDirection";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "StretchDirection";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::SwipeBehaviorOnInvoked>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.SwipeBehaviorOnInvoked";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "SwipeBehaviorOnInvoked";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::SwipeMode>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.SwipeMode";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "SwipeMode";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Symbol>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.Symbol";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "Symbol";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::TreeViewSelectionMode>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.TreeViewSelectionMode";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "TreeViewSelectionMode";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::TwoPaneViewMode>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.TwoPaneViewMode";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "TwoPaneViewMode";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::TwoPaneViewPriority>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.TwoPaneViewPriority";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "TwoPaneViewPriority";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::TwoPaneViewTallModeConfiguration>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.TwoPaneViewTallModeConfiguration";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "TwoPaneViewTallModeConfiguration";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::TwoPaneViewWideModeConfiguration>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.TwoPaneViewWideModeConfiguration";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "TwoPaneViewWideModeConfiguration";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::VirtualizationMode>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.VirtualizationMode";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "VirtualizationMode";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::WebViewExecutionMode>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.WebViewExecutionMode";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "WebViewExecutionMode";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::WebViewPermissionState>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.WebViewPermissionState";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "WebViewPermissionState";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::WebViewPermissionType>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.WebViewPermissionType";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "WebViewPermissionType";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ZoomMode>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ZoomMode";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ZoomMode";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::AnchorRequestedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.AnchorRequestedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "AnchorRequestedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::AppBar>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.AppBar";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "AppBar";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::AppBarButton>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.AppBarButton";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "AppBarButton";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::AppBarElementContainer>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.AppBarElementContainer";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "AppBarElementContainer";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::AppBarSeparator>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.AppBarSeparator";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "AppBarSeparator";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::AppBarToggleButton>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.AppBarToggleButton";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "AppBarToggleButton";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::AutoSuggestBox>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.AutoSuggestBox";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "AutoSuggestBox";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::AutoSuggestBoxQuerySubmittedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.AutoSuggestBoxQuerySubmittedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "AutoSuggestBoxQuerySubmittedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::AutoSuggestBoxSuggestionChosenEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.AutoSuggestBoxSuggestionChosenEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "AutoSuggestBoxSuggestionChosenEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::AutoSuggestBoxTextChangedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.AutoSuggestBoxTextChangedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "AutoSuggestBoxTextChangedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::BackClickEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.BackClickEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "BackClickEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::BitmapIcon>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.BitmapIcon";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "BitmapIcon";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::BitmapIconSource>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.BitmapIconSource";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "BitmapIconSource";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Border>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.Border";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "Border";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Button>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.Button";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "Button";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::CalendarDatePicker>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.CalendarDatePicker";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "CalendarDatePicker";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::CalendarDatePickerDateChangedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.CalendarDatePickerDateChangedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "CalendarDatePickerDateChangedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::CalendarView>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.CalendarView";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "CalendarView";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::CalendarViewDayItem>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.CalendarViewDayItem";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "CalendarViewDayItem";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::CalendarViewDayItemChangingEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.CalendarViewDayItemChangingEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "CalendarViewDayItemChangingEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::CalendarViewSelectedDatesChangedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.CalendarViewSelectedDatesChangedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "CalendarViewSelectedDatesChangedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::CandidateWindowBoundsChangedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.CandidateWindowBoundsChangedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "CandidateWindowBoundsChangedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Canvas>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.Canvas";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "Canvas";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::CaptureElement>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.CaptureElement";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "CaptureElement";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::CheckBox>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.CheckBox";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "CheckBox";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ChoosingGroupHeaderContainerEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ChoosingGroupHeaderContainerEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ChoosingGroupHeaderContainerEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ChoosingItemContainerEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ChoosingItemContainerEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ChoosingItemContainerEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::CleanUpVirtualizedItemEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.CleanUpVirtualizedItemEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "CleanUpVirtualizedItemEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ColorChangedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ColorChangedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ColorChangedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ColorPicker>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ColorPicker";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ColorPicker";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ColumnDefinition>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ColumnDefinition";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ColumnDefinition";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ColumnDefinitionCollection>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ColumnDefinitionCollection";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ColumnDefinitionCollection";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ComboBox>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ComboBox";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ComboBox";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ComboBoxItem>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ComboBoxItem";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ComboBoxItem";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ComboBoxTextSubmittedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ComboBoxTextSubmittedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ComboBoxTextSubmittedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::CommandBar>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.CommandBar";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "CommandBar";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::CommandBarFlyout>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.CommandBarFlyout";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "CommandBarFlyout";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::CommandBarOverflowPresenter>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.CommandBarOverflowPresenter";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "CommandBarOverflowPresenter";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ContainerContentChangingEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ContainerContentChangingEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ContainerContentChangingEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ContentControl>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ContentControl";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ContentControl";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ContentDialog>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ContentDialog";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ContentDialog";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ContentDialogButtonClickDeferral>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ContentDialogButtonClickDeferral";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ContentDialogButtonClickDeferral";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ContentDialogButtonClickEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ContentDialogButtonClickEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ContentDialogButtonClickEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ContentDialogClosedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ContentDialogClosedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ContentDialogClosedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ContentDialogClosingDeferral>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ContentDialogClosingDeferral";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ContentDialogClosingDeferral";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ContentDialogClosingEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ContentDialogClosingEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ContentDialogClosingEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ContentDialogOpenedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ContentDialogOpenedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ContentDialogOpenedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ContentLinkChangedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ContentLinkChangedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ContentLinkChangedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ContentPresenter>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ContentPresenter";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ContentPresenter";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ContextMenuEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ContextMenuEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ContextMenuEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Control>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.Control";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "Control";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ControlTemplate>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ControlTemplate";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ControlTemplate";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::DataTemplateSelector>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.DataTemplateSelector";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "DataTemplateSelector";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::DatePickedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.DatePickedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "DatePickedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::DatePicker>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.DatePicker";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "DatePicker";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::DatePickerFlyout>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.DatePickerFlyout";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "DatePickerFlyout";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::DatePickerFlyoutItem>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.DatePickerFlyoutItem";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "DatePickerFlyoutItem";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::DatePickerFlyoutPresenter>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.DatePickerFlyoutPresenter";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "DatePickerFlyoutPresenter";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::DatePickerSelectedValueChangedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.DatePickerSelectedValueChangedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "DatePickerSelectedValueChangedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::DatePickerValueChangedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.DatePickerValueChangedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "DatePickerValueChangedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::DragItemsCompletedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.DragItemsCompletedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "DragItemsCompletedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::DragItemsStartingEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.DragItemsStartingEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "DragItemsStartingEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::DropDownButton>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.DropDownButton";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "DropDownButton";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::DropDownButtonAutomationPeer>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.DropDownButtonAutomationPeer";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "DropDownButtonAutomationPeer";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::DynamicOverflowItemsChangingEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.DynamicOverflowItemsChangingEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "DynamicOverflowItemsChangingEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::FlipView>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.FlipView";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "FlipView";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::FlipViewItem>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.FlipViewItem";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "FlipViewItem";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Flyout>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.Flyout";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "Flyout";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::FlyoutPresenter>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.FlyoutPresenter";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "FlyoutPresenter";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::FocusDisengagedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.FocusDisengagedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "FocusDisengagedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::FocusEngagedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.FocusEngagedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "FocusEngagedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::FontIcon>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.FontIcon";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "FontIcon";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::FontIconSource>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.FontIconSource";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "FontIconSource";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Frame>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.Frame";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "Frame";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Grid>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.Grid";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "Grid";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::GridView>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.GridView";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "GridView";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::GridViewHeaderItem>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.GridViewHeaderItem";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "GridViewHeaderItem";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::GridViewItem>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.GridViewItem";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "GridViewItem";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::GroupItem>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.GroupItem";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "GroupItem";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::GroupStyle>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.GroupStyle";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "GroupStyle";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::GroupStyleSelector>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.GroupStyleSelector";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "GroupStyleSelector";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::HandwritingPanelClosedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.HandwritingPanelClosedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "HandwritingPanelClosedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::HandwritingPanelOpenedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.HandwritingPanelOpenedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "HandwritingPanelOpenedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::HandwritingView>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.HandwritingView";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "HandwritingView";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::HandwritingViewCandidatesChangedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.HandwritingViewCandidatesChangedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "HandwritingViewCandidatesChangedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::HandwritingViewTextSubmittedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.HandwritingViewTextSubmittedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "HandwritingViewTextSubmittedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Hub>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.Hub";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "Hub";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::HubSection>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.HubSection";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "HubSection";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::HubSectionCollection>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.HubSectionCollection";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "HubSectionCollection";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::HubSectionHeaderClickEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.HubSectionHeaderClickEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "HubSectionHeaderClickEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::HyperlinkButton>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.HyperlinkButton";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "HyperlinkButton";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::IconElement>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.IconElement";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "IconElement";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::IconSource>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.IconSource";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "IconSource";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::IconSourceElement>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.IconSourceElement";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "IconSourceElement";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Image>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.Image";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "Image";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::InkCanvas>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.InkCanvas";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "InkCanvas";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::InkToolbar>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.InkToolbar";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "InkToolbar";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::InkToolbarBallpointPenButton>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.InkToolbarBallpointPenButton";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "InkToolbarBallpointPenButton";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::InkToolbarCustomPen>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.InkToolbarCustomPen";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "InkToolbarCustomPen";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::InkToolbarCustomPenButton>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.InkToolbarCustomPenButton";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "InkToolbarCustomPenButton";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::InkToolbarCustomToggleButton>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.InkToolbarCustomToggleButton";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "InkToolbarCustomToggleButton";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::InkToolbarCustomToolButton>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.InkToolbarCustomToolButton";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "InkToolbarCustomToolButton";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::InkToolbarEraserButton>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.InkToolbarEraserButton";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "InkToolbarEraserButton";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::InkToolbarFlyoutItem>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.InkToolbarFlyoutItem";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "InkToolbarFlyoutItem";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::InkToolbarHighlighterButton>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.InkToolbarHighlighterButton";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "InkToolbarHighlighterButton";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::InkToolbarIsStencilButtonCheckedChangedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.InkToolbarIsStencilButtonCheckedChangedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "InkToolbarIsStencilButtonCheckedChangedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::InkToolbarMenuButton>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.InkToolbarMenuButton";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "InkToolbarMenuButton";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::InkToolbarPenButton>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.InkToolbarPenButton";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "InkToolbarPenButton";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::InkToolbarPenConfigurationControl>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.InkToolbarPenConfigurationControl";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "InkToolbarPenConfigurationControl";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::InkToolbarPencilButton>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.InkToolbarPencilButton";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "InkToolbarPencilButton";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::InkToolbarRulerButton>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.InkToolbarRulerButton";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "InkToolbarRulerButton";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::InkToolbarStencilButton>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.InkToolbarStencilButton";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "InkToolbarStencilButton";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::InkToolbarToggleButton>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.InkToolbarToggleButton";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "InkToolbarToggleButton";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::InkToolbarToolButton>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.InkToolbarToolButton";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "InkToolbarToolButton";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::IsTextTrimmedChangedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.IsTextTrimmedChangedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "IsTextTrimmedChangedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ItemClickEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ItemClickEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ItemClickEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ItemCollection>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ItemCollection";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ItemCollection";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ItemContainerGenerator>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ItemContainerGenerator";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ItemContainerGenerator";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ItemsControl>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ItemsControl";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ItemsControl";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ItemsPanelTemplate>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ItemsPanelTemplate";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ItemsPanelTemplate";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ItemsPickedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ItemsPickedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ItemsPickedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ItemsPresenter>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ItemsPresenter";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ItemsPresenter";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ItemsStackPanel>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ItemsStackPanel";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ItemsStackPanel";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ItemsWrapGrid>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ItemsWrapGrid";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ItemsWrapGrid";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ListBox>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ListBox";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ListBox";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ListBoxItem>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ListBoxItem";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ListBoxItem";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ListPickerFlyout>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ListPickerFlyout";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ListPickerFlyout";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ListPickerFlyoutPresenter>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ListPickerFlyoutPresenter";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ListPickerFlyoutPresenter";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ListView>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ListView";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ListView";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ListViewBase>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ListViewBase";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ListViewBase";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ListViewBaseHeaderItem>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ListViewBaseHeaderItem";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ListViewBaseHeaderItem";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ListViewHeaderItem>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ListViewHeaderItem";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ListViewHeaderItem";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ListViewItem>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ListViewItem";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ListViewItem";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ListViewPersistenceHelper>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ListViewPersistenceHelper";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ListViewPersistenceHelper";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::MediaElement>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.MediaElement";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "MediaElement";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::MediaPlayerElement>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.MediaPlayerElement";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "MediaPlayerElement";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::MediaPlayerPresenter>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.MediaPlayerPresenter";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "MediaPlayerPresenter";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::MediaTransportControls>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.MediaTransportControls";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "MediaTransportControls";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::MediaTransportControlsHelper>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.MediaTransportControlsHelper";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "MediaTransportControlsHelper";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::MenuBar>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.MenuBar";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "MenuBar";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::MenuBarItem>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.MenuBarItem";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "MenuBarItem";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::MenuBarItemFlyout>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.MenuBarItemFlyout";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "MenuBarItemFlyout";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::MenuFlyout>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.MenuFlyout";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "MenuFlyout";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::MenuFlyoutItem>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.MenuFlyoutItem";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "MenuFlyoutItem";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::MenuFlyoutItemBase>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.MenuFlyoutItemBase";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "MenuFlyoutItemBase";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::MenuFlyoutPresenter>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.MenuFlyoutPresenter";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "MenuFlyoutPresenter";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::MenuFlyoutSeparator>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.MenuFlyoutSeparator";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "MenuFlyoutSeparator";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::MenuFlyoutSubItem>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.MenuFlyoutSubItem";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "MenuFlyoutSubItem";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::NavigationView>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.NavigationView";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "NavigationView";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::NavigationViewBackRequestedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.NavigationViewBackRequestedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "NavigationViewBackRequestedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::NavigationViewDisplayModeChangedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.NavigationViewDisplayModeChangedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "NavigationViewDisplayModeChangedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::NavigationViewItem>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.NavigationViewItem";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "NavigationViewItem";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::NavigationViewItemBase>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.NavigationViewItemBase";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "NavigationViewItemBase";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::NavigationViewItemHeader>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.NavigationViewItemHeader";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "NavigationViewItemHeader";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::NavigationViewItemInvokedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.NavigationViewItemInvokedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "NavigationViewItemInvokedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::NavigationViewItemSeparator>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.NavigationViewItemSeparator";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "NavigationViewItemSeparator";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::NavigationViewList>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.NavigationViewList";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "NavigationViewList";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::NavigationViewPaneClosingEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.NavigationViewPaneClosingEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "NavigationViewPaneClosingEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::NavigationViewSelectionChangedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.NavigationViewSelectionChangedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "NavigationViewSelectionChangedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::NavigationViewTemplateSettings>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.NavigationViewTemplateSettings";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "NavigationViewTemplateSettings";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::NotifyEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.NotifyEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "NotifyEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Page>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.Page";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "Page";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Panel>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.Panel";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "Panel";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ParallaxView>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ParallaxView";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ParallaxView";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::PasswordBox>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.PasswordBox";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "PasswordBox";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::PasswordBoxPasswordChangingEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.PasswordBoxPasswordChangingEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "PasswordBoxPasswordChangingEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::PathIcon>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.PathIcon";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "PathIcon";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::PathIconSource>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.PathIconSource";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "PathIconSource";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::PersonPicture>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.PersonPicture";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "PersonPicture";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::PickerConfirmedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.PickerConfirmedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "PickerConfirmedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::PickerFlyout>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.PickerFlyout";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "PickerFlyout";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::PickerFlyoutPresenter>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.PickerFlyoutPresenter";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "PickerFlyoutPresenter";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Pivot>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.Pivot";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "Pivot";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::PivotItem>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.PivotItem";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "PivotItem";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::PivotItemEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.PivotItemEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "PivotItemEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ProgressBar>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ProgressBar";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ProgressBar";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ProgressRing>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ProgressRing";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ProgressRing";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::RadioButton>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.RadioButton";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "RadioButton";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::RatingControl>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.RatingControl";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "RatingControl";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::RatingItemFontInfo>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.RatingItemFontInfo";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "RatingItemFontInfo";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::RatingItemImageInfo>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.RatingItemImageInfo";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "RatingItemImageInfo";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::RatingItemInfo>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.RatingItemInfo";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "RatingItemInfo";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::RefreshContainer>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.RefreshContainer";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "RefreshContainer";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::RefreshInteractionRatioChangedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.RefreshInteractionRatioChangedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "RefreshInteractionRatioChangedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::RefreshRequestedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.RefreshRequestedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "RefreshRequestedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::RefreshStateChangedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.RefreshStateChangedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "RefreshStateChangedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::RefreshVisualizer>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.RefreshVisualizer";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "RefreshVisualizer";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::RelativePanel>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.RelativePanel";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "RelativePanel";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::RichEditBox>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.RichEditBox";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "RichEditBox";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::RichEditBoxSelectionChangingEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.RichEditBoxSelectionChangingEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "RichEditBoxSelectionChangingEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::RichEditBoxTextChangingEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.RichEditBoxTextChangingEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "RichEditBoxTextChangingEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::RichTextBlock>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.RichTextBlock";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "RichTextBlock";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::RichTextBlockOverflow>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.RichTextBlockOverflow";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "RichTextBlockOverflow";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::RowDefinition>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.RowDefinition";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "RowDefinition";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::RowDefinitionCollection>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.RowDefinitionCollection";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "RowDefinitionCollection";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ScrollContentPresenter>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ScrollContentPresenter";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ScrollContentPresenter";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ScrollViewer>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ScrollViewer";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ScrollViewer";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ScrollViewerView>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ScrollViewerView";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ScrollViewerView";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ScrollViewerViewChangedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ScrollViewerViewChangedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ScrollViewerViewChangedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ScrollViewerViewChangingEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ScrollViewerViewChangingEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ScrollViewerViewChangingEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::SearchBox>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.SearchBox";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "SearchBox";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::SearchBoxQueryChangedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.SearchBoxQueryChangedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "SearchBoxQueryChangedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::SearchBoxQuerySubmittedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.SearchBoxQuerySubmittedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "SearchBoxQuerySubmittedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::SearchBoxResultSuggestionChosenEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.SearchBoxResultSuggestionChosenEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "SearchBoxResultSuggestionChosenEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::SearchBoxSuggestionsRequestedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.SearchBoxSuggestionsRequestedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "SearchBoxSuggestionsRequestedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::SectionsInViewChangedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.SectionsInViewChangedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "SectionsInViewChangedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::SelectionChangedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.SelectionChangedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "SelectionChangedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::SemanticZoom>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.SemanticZoom";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "SemanticZoom";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::SemanticZoomLocation>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.SemanticZoomLocation";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "SemanticZoomLocation";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::SemanticZoomViewChangedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.SemanticZoomViewChangedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "SemanticZoomViewChangedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::SettingsFlyout>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.SettingsFlyout";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "SettingsFlyout";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Slider>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.Slider";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "Slider";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::SplitButton>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.SplitButton";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "SplitButton";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::SplitButtonAutomationPeer>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.SplitButtonAutomationPeer";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "SplitButtonAutomationPeer";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::SplitButtonClickEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.SplitButtonClickEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "SplitButtonClickEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::SplitView>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.SplitView";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "SplitView";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::SplitViewPaneClosingEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.SplitViewPaneClosingEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "SplitViewPaneClosingEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::StackPanel>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.StackPanel";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "StackPanel";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::StyleSelector>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.StyleSelector";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "StyleSelector";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::SwapChainBackgroundPanel>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.SwapChainBackgroundPanel";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "SwapChainBackgroundPanel";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::SwapChainPanel>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.SwapChainPanel";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "SwapChainPanel";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::SwipeControl>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.SwipeControl";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "SwipeControl";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::SwipeItem>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.SwipeItem";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "SwipeItem";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::SwipeItemInvokedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.SwipeItemInvokedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "SwipeItemInvokedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::SwipeItems>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.SwipeItems";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "SwipeItems";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::SymbolIcon>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.SymbolIcon";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "SymbolIcon";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::SymbolIconSource>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.SymbolIconSource";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "SymbolIconSource";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::TextBlock>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.TextBlock";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "TextBlock";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::TextBox>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.TextBox";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "TextBox";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::TextBoxBeforeTextChangingEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.TextBoxBeforeTextChangingEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "TextBoxBeforeTextChangingEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::TextBoxSelectionChangingEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.TextBoxSelectionChangingEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "TextBoxSelectionChangingEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::TextBoxTextChangingEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.TextBoxTextChangingEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "TextBoxTextChangingEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::TextChangedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.TextChangedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "TextChangedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::TextCommandBarFlyout>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.TextCommandBarFlyout";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "TextCommandBarFlyout";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::TextCompositionChangedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.TextCompositionChangedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "TextCompositionChangedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::TextCompositionEndedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.TextCompositionEndedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "TextCompositionEndedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::TextCompositionStartedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.TextCompositionStartedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "TextCompositionStartedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::TextControlCopyingToClipboardEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.TextControlCopyingToClipboardEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "TextControlCopyingToClipboardEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::TextControlCuttingToClipboardEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.TextControlCuttingToClipboardEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "TextControlCuttingToClipboardEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::TextControlPasteEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.TextControlPasteEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "TextControlPasteEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::TimePickedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.TimePickedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "TimePickedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::TimePicker>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.TimePicker";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "TimePicker";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::TimePickerFlyout>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.TimePickerFlyout";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "TimePickerFlyout";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::TimePickerFlyoutPresenter>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.TimePickerFlyoutPresenter";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "TimePickerFlyoutPresenter";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::TimePickerSelectedValueChangedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.TimePickerSelectedValueChangedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "TimePickerSelectedValueChangedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::TimePickerValueChangedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.TimePickerValueChangedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "TimePickerValueChangedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ToggleMenuFlyoutItem>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ToggleMenuFlyoutItem";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ToggleMenuFlyoutItem";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ToggleSplitButton>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ToggleSplitButton";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ToggleSplitButton";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ToggleSplitButtonAutomationPeer>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ToggleSplitButtonAutomationPeer";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ToggleSplitButtonAutomationPeer";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ToggleSplitButtonIsCheckedChangedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ToggleSplitButtonIsCheckedChangedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ToggleSplitButtonIsCheckedChangedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ToggleSwitch>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ToggleSwitch";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ToggleSwitch";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ToolTip>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ToolTip";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ToolTip";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ToolTipService>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.ToolTipService";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "ToolTipService";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::TreeView>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.TreeView";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "TreeView";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::TreeViewCollapsedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.TreeViewCollapsedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "TreeViewCollapsedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::TreeViewDragItemsCompletedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.TreeViewDragItemsCompletedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "TreeViewDragItemsCompletedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::TreeViewDragItemsStartingEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.TreeViewDragItemsStartingEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "TreeViewDragItemsStartingEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::TreeViewExpandingEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.TreeViewExpandingEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "TreeViewExpandingEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::TreeViewItem>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.TreeViewItem";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "TreeViewItem";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::TreeViewItemInvokedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.TreeViewItemInvokedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "TreeViewItemInvokedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::TreeViewItemTemplateSettings>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.TreeViewItemTemplateSettings";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "TreeViewItemTemplateSettings";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::TreeViewList>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.TreeViewList";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "TreeViewList";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::TreeViewNode>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.TreeViewNode";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "TreeViewNode";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::TwoPaneView>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.TwoPaneView";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "TwoPaneView";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::UIElementCollection>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.UIElementCollection";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "UIElementCollection";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::UserControl>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.UserControl";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "UserControl";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::VariableSizedWrapGrid>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.VariableSizedWrapGrid";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "VariableSizedWrapGrid";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Viewbox>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.Viewbox";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "Viewbox";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::VirtualizingPanel>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.VirtualizingPanel";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "VirtualizingPanel";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::VirtualizingStackPanel>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.VirtualizingStackPanel";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "VirtualizingStackPanel";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::WebView>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.WebView";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "WebView";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::WebViewBrush>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.WebViewBrush";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "WebViewBrush";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::WebViewContentLoadingEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.WebViewContentLoadingEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "WebViewContentLoadingEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::WebViewDOMContentLoadedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.WebViewDOMContentLoadedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "WebViewDOMContentLoadedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::WebViewDeferredPermissionRequest>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.WebViewDeferredPermissionRequest";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "WebViewDeferredPermissionRequest";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::WebViewLongRunningScriptDetectedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.WebViewLongRunningScriptDetectedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "WebViewLongRunningScriptDetectedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::WebViewNavigationCompletedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.WebViewNavigationCompletedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "WebViewNavigationCompletedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::WebViewNavigationFailedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.WebViewNavigationFailedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "WebViewNavigationFailedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::WebViewNavigationStartingEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.WebViewNavigationStartingEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "WebViewNavigationStartingEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::WebViewNewWindowRequestedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.WebViewNewWindowRequestedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "WebViewNewWindowRequestedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::WebViewPermissionRequest>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.WebViewPermissionRequest";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "WebViewPermissionRequest";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::WebViewPermissionRequestedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.WebViewPermissionRequestedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "WebViewPermissionRequestedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::WebViewSeparateProcessLostEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.WebViewSeparateProcessLostEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "WebViewSeparateProcessLostEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::WebViewSettings>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.WebViewSettings";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "WebViewSettings";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::WebViewUnsupportedUriSchemeIdentifiedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.WebViewUnsupportedUriSchemeIdentifiedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "WebViewUnsupportedUriSchemeIdentifiedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::WebViewUnviewableContentIdentifiedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.WebViewUnviewableContentIdentifiedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "WebViewUnviewableContentIdentifiedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::WebViewWebResourceRequestedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.WebViewWebResourceRequestedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "WebViewWebResourceRequestedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::WrapGrid>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.WrapGrid";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "WrapGrid";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ICommandBarElement>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls._ICommandBarElement";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "_ICommandBarElement";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ICommandBarElement2>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls._ICommandBarElement2";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "_ICommandBarElement2";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::IInsertionPanel>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls._IInsertionPanel";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "_IInsertionPanel";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::IItemContainerMapping>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls._IItemContainerMapping";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "_IItemContainerMapping";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::INavigate>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls._INavigate";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "_INavigate";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::IScrollAnchorProvider>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls._IScrollAnchorProvider";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "_IScrollAnchorProvider";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::ISemanticZoomInformation>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls._ISemanticZoomInformation";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls";
        static constexpr const char* type_name = "_ISemanticZoomInformation";
    };
}

#if __has_include("py.Windows.ApplicationModel.Contacts.h")
#include "py.Windows.ApplicationModel.Contacts.h"
#endif

#if __has_include("py.Windows.ApplicationModel.DataTransfer.h")
#include "py.Windows.ApplicationModel.DataTransfer.h"
#endif

#if __has_include("py.Windows.ApplicationModel.Search.h")
#include "py.Windows.ApplicationModel.Search.h"
#endif

#if __has_include("py.Windows.Foundation.h")
#include "py.Windows.Foundation.h"
#endif

#if __has_include("py.Windows.Foundation.Collections.h")
#include "py.Windows.Foundation.Collections.h"
#endif

#if __has_include("py.Windows.Globalization.h")
#include "py.Windows.Globalization.h"
#endif

#if __has_include("py.Windows.Media.Capture.h")
#include "py.Windows.Media.Capture.h"
#endif

#if __has_include("py.Windows.Media.Casting.h")
#include "py.Windows.Media.Casting.h"
#endif

#if __has_include("py.Windows.Media.Core.h")
#include "py.Windows.Media.Core.h"
#endif

#if __has_include("py.Windows.Media.PlayTo.h")
#include "py.Windows.Media.PlayTo.h"
#endif

#if __has_include("py.Windows.Media.Playback.h")
#include "py.Windows.Media.Playback.h"
#endif

#if __has_include("py.Windows.Media.Protection.h")
#include "py.Windows.Media.Protection.h"
#endif

#if __has_include("py.Windows.Storage.Streams.h")
#include "py.Windows.Storage.Streams.h"
#endif

#if __has_include("py.Windows.System.h")
#include "py.Windows.System.h"
#endif

#if __has_include("py.Windows.UI.h")
#include "py.Windows.UI.h"
#endif

#if __has_include("py.Windows.UI.Composition.h")
#include "py.Windows.UI.Composition.h"
#endif

#if __has_include("py.Windows.UI.Core.h")
#include "py.Windows.UI.Core.h"
#endif

#if __has_include("py.Windows.UI.Input.Inking.h")
#include "py.Windows.UI.Input.Inking.h"
#endif

#if __has_include("py.Windows.UI.Text.h")
#include "py.Windows.UI.Text.h"
#endif

#if __has_include("py.Windows.UI.Xaml.h")
#include "py.Windows.UI.Xaml.h"
#endif

#if __has_include("py.Windows.UI.Xaml.Automation.h")
#include "py.Windows.UI.Xaml.Automation.h"
#endif

#if __has_include("py.Windows.UI.Xaml.Automation.Peers.h")
#include "py.Windows.UI.Xaml.Automation.Peers.h"
#endif

#if __has_include("py.Windows.UI.Xaml.Controls.Primitives.h")
#include "py.Windows.UI.Xaml.Controls.Primitives.h"
#endif

#if __has_include("py.Windows.UI.Xaml.Data.h")
#include "py.Windows.UI.Xaml.Data.h"
#endif

#if __has_include("py.Windows.UI.Xaml.Documents.h")
#include "py.Windows.UI.Xaml.Documents.h"
#endif

#if __has_include("py.Windows.UI.Xaml.Input.h")
#include "py.Windows.UI.Xaml.Input.h"
#endif

#if __has_include("py.Windows.UI.Xaml.Interop.h")
#include "py.Windows.UI.Xaml.Interop.h"
#endif

#if __has_include("py.Windows.UI.Xaml.Media.h")
#include "py.Windows.UI.Xaml.Media.h"
#endif

#if __has_include("py.Windows.UI.Xaml.Media.Animation.h")
#include "py.Windows.UI.Xaml.Media.Animation.h"
#endif

#if __has_include("py.Windows.UI.Xaml.Navigation.h")
#include "py.Windows.UI.Xaml.Navigation.h"
#endif

#if __has_include("py.Windows.Web.h")
#include "py.Windows.Web.h"
#endif

#if __has_include("py.Windows.Web.Http.h")
#include "py.Windows.Web.Http.h"
#endif

namespace py::impl::Windows::UI::Xaml::Controls
{
    struct BackClickEventHandler
    {
        static winrt::Windows::UI::Xaml::Controls::BackClickEventHandler get(PyObject* callable)
        {
            py::delegate_callable _delegate{ callable };

            return [delegate = std::move(_delegate)](winrt::Windows::Foundation::IInspectable const& param0, winrt::Windows::UI::Xaml::Controls::BackClickEventArgs const& param1)
            {
                auto gil = py::ensure_gil();

                try
                {
                    py::pyobj_handle py_param0{py::convert(param0)};
                    if (!py_param0)
                    {
                        throw python_exception();
                    }

                    py::pyobj_handle py_param1{py::convert(param1)};
                    if (!py_param1)
                    {
                        throw python_exception();
                    }

                    py::pyobj_handle args{PyTuple_Pack(2, py_param0.get(), py_param1.get())};
                    if (!args)
                    {
                        throw python_exception();
                    }

                    py::pyobj_handle return_value{PyObject_CallObject(delegate.callable(), args.get())};
                    if (!return_value)
                    {
                        throw python_exception();
                    }
                }
                catch (python_exception)
                {
                    py::write_unraisable_and_throw();
                }
            };
        };
    };

    struct CalendarViewDayItemChangingEventHandler
    {
        static winrt::Windows::UI::Xaml::Controls::CalendarViewDayItemChangingEventHandler get(PyObject* callable)
        {
            py::delegate_callable _delegate{ callable };

            return [delegate = std::move(_delegate)](winrt::Windows::UI::Xaml::Controls::CalendarView const& param0, winrt::Windows::UI::Xaml::Controls::CalendarViewDayItemChangingEventArgs const& param1)
            {
                auto gil = py::ensure_gil();

                try
                {
                    py::pyobj_handle py_param0{py::convert(param0)};
                    if (!py_param0)
                    {
                        throw python_exception();
                    }

                    py::pyobj_handle py_param1{py::convert(param1)};
                    if (!py_param1)
                    {
                        throw python_exception();
                    }

                    py::pyobj_handle args{PyTuple_Pack(2, py_param0.get(), py_param1.get())};
                    if (!args)
                    {
                        throw python_exception();
                    }

                    py::pyobj_handle return_value{PyObject_CallObject(delegate.callable(), args.get())};
                    if (!return_value)
                    {
                        throw python_exception();
                    }
                }
                catch (python_exception)
                {
                    py::write_unraisable_and_throw();
                }
            };
        };
    };

    struct CleanUpVirtualizedItemEventHandler
    {
        static winrt::Windows::UI::Xaml::Controls::CleanUpVirtualizedItemEventHandler get(PyObject* callable)
        {
            py::delegate_callable _delegate{ callable };

            return [delegate = std::move(_delegate)](winrt::Windows::Foundation::IInspectable const& param0, winrt::Windows::UI::Xaml::Controls::CleanUpVirtualizedItemEventArgs const& param1)
            {
                auto gil = py::ensure_gil();

                try
                {
                    py::pyobj_handle py_param0{py::convert(param0)};
                    if (!py_param0)
                    {
                        throw python_exception();
                    }

                    py::pyobj_handle py_param1{py::convert(param1)};
                    if (!py_param1)
                    {
                        throw python_exception();
                    }

                    py::pyobj_handle args{PyTuple_Pack(2, py_param0.get(), py_param1.get())};
                    if (!args)
                    {
                        throw python_exception();
                    }

                    py::pyobj_handle return_value{PyObject_CallObject(delegate.callable(), args.get())};
                    if (!return_value)
                    {
                        throw python_exception();
                    }
                }
                catch (python_exception)
                {
                    py::write_unraisable_and_throw();
                }
            };
        };
    };

    struct ContextMenuOpeningEventHandler
    {
        static winrt::Windows::UI::Xaml::Controls::ContextMenuOpeningEventHandler get(PyObject* callable)
        {
            py::delegate_callable _delegate{ callable };

            return [delegate = std::move(_delegate)](winrt::Windows::Foundation::IInspectable const& param0, winrt::Windows::UI::Xaml::Controls::ContextMenuEventArgs const& param1)
            {
                auto gil = py::ensure_gil();

                try
                {
                    py::pyobj_handle py_param0{py::convert(param0)};
                    if (!py_param0)
                    {
                        throw python_exception();
                    }

                    py::pyobj_handle py_param1{py::convert(param1)};
                    if (!py_param1)
                    {
                        throw python_exception();
                    }

                    py::pyobj_handle args{PyTuple_Pack(2, py_param0.get(), py_param1.get())};
                    if (!args)
                    {
                        throw python_exception();
                    }

                    py::pyobj_handle return_value{PyObject_CallObject(delegate.callable(), args.get())};
                    if (!return_value)
                    {
                        throw python_exception();
                    }
                }
                catch (python_exception)
                {
                    py::write_unraisable_and_throw();
                }
            };
        };
    };

    struct DragItemsStartingEventHandler
    {
        static winrt::Windows::UI::Xaml::Controls::DragItemsStartingEventHandler get(PyObject* callable)
        {
            py::delegate_callable _delegate{ callable };

            return [delegate = std::move(_delegate)](winrt::Windows::Foundation::IInspectable const& param0, winrt::Windows::UI::Xaml::Controls::DragItemsStartingEventArgs const& param1)
            {
                auto gil = py::ensure_gil();

                try
                {
                    py::pyobj_handle py_param0{py::convert(param0)};
                    if (!py_param0)
                    {
                        throw python_exception();
                    }

                    py::pyobj_handle py_param1{py::convert(param1)};
                    if (!py_param1)
                    {
                        throw python_exception();
                    }

                    py::pyobj_handle args{PyTuple_Pack(2, py_param0.get(), py_param1.get())};
                    if (!args)
                    {
                        throw python_exception();
                    }

                    py::pyobj_handle return_value{PyObject_CallObject(delegate.callable(), args.get())};
                    if (!return_value)
                    {
                        throw python_exception();
                    }
                }
                catch (python_exception)
                {
                    py::write_unraisable_and_throw();
                }
            };
        };
    };

    struct HubSectionHeaderClickEventHandler
    {
        static winrt::Windows::UI::Xaml::Controls::HubSectionHeaderClickEventHandler get(PyObject* callable)
        {
            py::delegate_callable _delegate{ callable };

            return [delegate = std::move(_delegate)](winrt::Windows::Foundation::IInspectable const& param0, winrt::Windows::UI::Xaml::Controls::HubSectionHeaderClickEventArgs const& param1)
            {
                auto gil = py::ensure_gil();

                try
                {
                    py::pyobj_handle py_param0{py::convert(param0)};
                    if (!py_param0)
                    {
                        throw python_exception();
                    }

                    py::pyobj_handle py_param1{py::convert(param1)};
                    if (!py_param1)
                    {
                        throw python_exception();
                    }

                    py::pyobj_handle args{PyTuple_Pack(2, py_param0.get(), py_param1.get())};
                    if (!args)
                    {
                        throw python_exception();
                    }

                    py::pyobj_handle return_value{PyObject_CallObject(delegate.callable(), args.get())};
                    if (!return_value)
                    {
                        throw python_exception();
                    }
                }
                catch (python_exception)
                {
                    py::write_unraisable_and_throw();
                }
            };
        };
    };

    struct ItemClickEventHandler
    {
        static winrt::Windows::UI::Xaml::Controls::ItemClickEventHandler get(PyObject* callable)
        {
            py::delegate_callable _delegate{ callable };

            return [delegate = std::move(_delegate)](winrt::Windows::Foundation::IInspectable const& param0, winrt::Windows::UI::Xaml::Controls::ItemClickEventArgs const& param1)
            {
                auto gil = py::ensure_gil();

                try
                {
                    py::pyobj_handle py_param0{py::convert(param0)};
                    if (!py_param0)
                    {
                        throw python_exception();
                    }

                    py::pyobj_handle py_param1{py::convert(param1)};
                    if (!py_param1)
                    {
                        throw python_exception();
                    }

                    py::pyobj_handle args{PyTuple_Pack(2, py_param0.get(), py_param1.get())};
                    if (!args)
                    {
                        throw python_exception();
                    }

                    py::pyobj_handle return_value{PyObject_CallObject(delegate.callable(), args.get())};
                    if (!return_value)
                    {
                        throw python_exception();
                    }
                }
                catch (python_exception)
                {
                    py::write_unraisable_and_throw();
                }
            };
        };
    };

    struct ListViewItemToKeyHandler
    {
        static winrt::Windows::UI::Xaml::Controls::ListViewItemToKeyHandler get(PyObject* callable)
        {
            py::delegate_callable _delegate{ callable };

            return [delegate = std::move(_delegate)](winrt::Windows::Foundation::IInspectable const& param0)
            {
                auto gil = py::ensure_gil();

                try
                {
                    py::pyobj_handle py_param0{py::convert(param0)};
                    if (!py_param0)
                    {
                        throw python_exception();
                    }

                    py::pyobj_handle return_value{PyObject_CallOneArg(delegate.callable(), py_param0.get())};
                    if (!return_value)
                    {
                        throw python_exception();
                    }

                    return py::convert_to<winrt::hstring>(return_value.get());
                }
                catch (python_exception)
                {
                    py::write_unraisable_and_throw();
                }
            };
        };
    };

    struct ListViewKeyToItemHandler
    {
        static winrt::Windows::UI::Xaml::Controls::ListViewKeyToItemHandler get(PyObject* callable)
        {
            py::delegate_callable _delegate{ callable };

            return [delegate = std::move(_delegate)](winrt::hstring const& param0)
            {
                auto gil = py::ensure_gil();

                try
                {
                    py::pyobj_handle py_param0{py::convert(param0)};
                    if (!py_param0)
                    {
                        throw python_exception();
                    }

                    py::pyobj_handle return_value{PyObject_CallOneArg(delegate.callable(), py_param0.get())};
                    if (!return_value)
                    {
                        throw python_exception();
                    }

                    return py::convert_to<winrt::Windows::Foundation::IAsyncOperation<winrt::Windows::Foundation::IInspectable>>(return_value.get());
                }
                catch (python_exception)
                {
                    py::write_unraisable_and_throw();
                }
            };
        };
    };

    struct NotifyEventHandler
    {
        static winrt::Windows::UI::Xaml::Controls::NotifyEventHandler get(PyObject* callable)
        {
            py::delegate_callable _delegate{ callable };

            return [delegate = std::move(_delegate)](winrt::Windows::Foundation::IInspectable const& param0, winrt::Windows::UI::Xaml::Controls::NotifyEventArgs const& param1)
            {
                auto gil = py::ensure_gil();

                try
                {
                    py::pyobj_handle py_param0{py::convert(param0)};
                    if (!py_param0)
                    {
                        throw python_exception();
                    }

                    py::pyobj_handle py_param1{py::convert(param1)};
                    if (!py_param1)
                    {
                        throw python_exception();
                    }

                    py::pyobj_handle args{PyTuple_Pack(2, py_param0.get(), py_param1.get())};
                    if (!args)
                    {
                        throw python_exception();
                    }

                    py::pyobj_handle return_value{PyObject_CallObject(delegate.callable(), args.get())};
                    if (!return_value)
                    {
                        throw python_exception();
                    }
                }
                catch (python_exception)
                {
                    py::write_unraisable_and_throw();
                }
            };
        };
    };

    struct SectionsInViewChangedEventHandler
    {
        static winrt::Windows::UI::Xaml::Controls::SectionsInViewChangedEventHandler get(PyObject* callable)
        {
            py::delegate_callable _delegate{ callable };

            return [delegate = std::move(_delegate)](winrt::Windows::Foundation::IInspectable const& param0, winrt::Windows::UI::Xaml::Controls::SectionsInViewChangedEventArgs const& param1)
            {
                auto gil = py::ensure_gil();

                try
                {
                    py::pyobj_handle py_param0{py::convert(param0)};
                    if (!py_param0)
                    {
                        throw python_exception();
                    }

                    py::pyobj_handle py_param1{py::convert(param1)};
                    if (!py_param1)
                    {
                        throw python_exception();
                    }

                    py::pyobj_handle args{PyTuple_Pack(2, py_param0.get(), py_param1.get())};
                    if (!args)
                    {
                        throw python_exception();
                    }

                    py::pyobj_handle return_value{PyObject_CallObject(delegate.callable(), args.get())};
                    if (!return_value)
                    {
                        throw python_exception();
                    }
                }
                catch (python_exception)
                {
                    py::write_unraisable_and_throw();
                }
            };
        };
    };

    struct SelectionChangedEventHandler
    {
        static winrt::Windows::UI::Xaml::Controls::SelectionChangedEventHandler get(PyObject* callable)
        {
            py::delegate_callable _delegate{ callable };

            return [delegate = std::move(_delegate)](winrt::Windows::Foundation::IInspectable const& param0, winrt::Windows::UI::Xaml::Controls::SelectionChangedEventArgs const& param1)
            {
                auto gil = py::ensure_gil();

                try
                {
                    py::pyobj_handle py_param0{py::convert(param0)};
                    if (!py_param0)
                    {
                        throw python_exception();
                    }

                    py::pyobj_handle py_param1{py::convert(param1)};
                    if (!py_param1)
                    {
                        throw python_exception();
                    }

                    py::pyobj_handle args{PyTuple_Pack(2, py_param0.get(), py_param1.get())};
                    if (!args)
                    {
                        throw python_exception();
                    }

                    py::pyobj_handle return_value{PyObject_CallObject(delegate.callable(), args.get())};
                    if (!return_value)
                    {
                        throw python_exception();
                    }
                }
                catch (python_exception)
                {
                    py::write_unraisable_and_throw();
                }
            };
        };
    };

    struct SemanticZoomViewChangedEventHandler
    {
        static winrt::Windows::UI::Xaml::Controls::SemanticZoomViewChangedEventHandler get(PyObject* callable)
        {
            py::delegate_callable _delegate{ callable };

            return [delegate = std::move(_delegate)](winrt::Windows::Foundation::IInspectable const& param0, winrt::Windows::UI::Xaml::Controls::SemanticZoomViewChangedEventArgs const& param1)
            {
                auto gil = py::ensure_gil();

                try
                {
                    py::pyobj_handle py_param0{py::convert(param0)};
                    if (!py_param0)
                    {
                        throw python_exception();
                    }

                    py::pyobj_handle py_param1{py::convert(param1)};
                    if (!py_param1)
                    {
                        throw python_exception();
                    }

                    py::pyobj_handle args{PyTuple_Pack(2, py_param0.get(), py_param1.get())};
                    if (!args)
                    {
                        throw python_exception();
                    }

                    py::pyobj_handle return_value{PyObject_CallObject(delegate.callable(), args.get())};
                    if (!return_value)
                    {
                        throw python_exception();
                    }
                }
                catch (python_exception)
                {
                    py::write_unraisable_and_throw();
                }
            };
        };
    };

    struct TextChangedEventHandler
    {
        static winrt::Windows::UI::Xaml::Controls::TextChangedEventHandler get(PyObject* callable)
        {
            py::delegate_callable _delegate{ callable };

            return [delegate = std::move(_delegate)](winrt::Windows::Foundation::IInspectable const& param0, winrt::Windows::UI::Xaml::Controls::TextChangedEventArgs const& param1)
            {
                auto gil = py::ensure_gil();

                try
                {
                    py::pyobj_handle py_param0{py::convert(param0)};
                    if (!py_param0)
                    {
                        throw python_exception();
                    }

                    py::pyobj_handle py_param1{py::convert(param1)};
                    if (!py_param1)
                    {
                        throw python_exception();
                    }

                    py::pyobj_handle args{PyTuple_Pack(2, py_param0.get(), py_param1.get())};
                    if (!args)
                    {
                        throw python_exception();
                    }

                    py::pyobj_handle return_value{PyObject_CallObject(delegate.callable(), args.get())};
                    if (!return_value)
                    {
                        throw python_exception();
                    }
                }
                catch (python_exception)
                {
                    py::write_unraisable_and_throw();
                }
            };
        };
    };

    struct TextControlPasteEventHandler
    {
        static winrt::Windows::UI::Xaml::Controls::TextControlPasteEventHandler get(PyObject* callable)
        {
            py::delegate_callable _delegate{ callable };

            return [delegate = std::move(_delegate)](winrt::Windows::Foundation::IInspectable const& param0, winrt::Windows::UI::Xaml::Controls::TextControlPasteEventArgs const& param1)
            {
                auto gil = py::ensure_gil();

                try
                {
                    py::pyobj_handle py_param0{py::convert(param0)};
                    if (!py_param0)
                    {
                        throw python_exception();
                    }

                    py::pyobj_handle py_param1{py::convert(param1)};
                    if (!py_param1)
                    {
                        throw python_exception();
                    }

                    py::pyobj_handle args{PyTuple_Pack(2, py_param0.get(), py_param1.get())};
                    if (!args)
                    {
                        throw python_exception();
                    }

                    py::pyobj_handle return_value{PyObject_CallObject(delegate.callable(), args.get())};
                    if (!return_value)
                    {
                        throw python_exception();
                    }
                }
                catch (python_exception)
                {
                    py::write_unraisable_and_throw();
                }
            };
        };
    };

    struct WebViewNavigationFailedEventHandler
    {
        static winrt::Windows::UI::Xaml::Controls::WebViewNavigationFailedEventHandler get(PyObject* callable)
        {
            py::delegate_callable _delegate{ callable };

            return [delegate = std::move(_delegate)](winrt::Windows::Foundation::IInspectable const& param0, winrt::Windows::UI::Xaml::Controls::WebViewNavigationFailedEventArgs const& param1)
            {
                auto gil = py::ensure_gil();

                try
                {
                    py::pyobj_handle py_param0{py::convert(param0)};
                    if (!py_param0)
                    {
                        throw python_exception();
                    }

                    py::pyobj_handle py_param1{py::convert(param1)};
                    if (!py_param1)
                    {
                        throw python_exception();
                    }

                    py::pyobj_handle args{PyTuple_Pack(2, py_param0.get(), py_param1.get())};
                    if (!args)
                    {
                        throw python_exception();
                    }

                    py::pyobj_handle return_value{PyObject_CallObject(delegate.callable(), args.get())};
                    if (!return_value)
                    {
                        throw python_exception();
                    }
                }
                catch (python_exception)
                {
                    py::write_unraisable_and_throw();
                }
            };
        };
    };
}

namespace py::wrapper::Windows::UI::Xaml::Controls
{
    using AnchorRequestedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::AnchorRequestedEventArgs>;
    using AppBar = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::AppBar>;
    using AppBarButton = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::AppBarButton>;
    using AppBarElementContainer = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::AppBarElementContainer>;
    using AppBarSeparator = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::AppBarSeparator>;
    using AppBarToggleButton = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::AppBarToggleButton>;
    using AutoSuggestBox = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::AutoSuggestBox>;
    using AutoSuggestBoxQuerySubmittedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::AutoSuggestBoxQuerySubmittedEventArgs>;
    using AutoSuggestBoxSuggestionChosenEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::AutoSuggestBoxSuggestionChosenEventArgs>;
    using AutoSuggestBoxTextChangedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::AutoSuggestBoxTextChangedEventArgs>;
    using BackClickEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::BackClickEventArgs>;
    using BitmapIcon = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::BitmapIcon>;
    using BitmapIconSource = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::BitmapIconSource>;
    using Border = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::Border>;
    using Button = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::Button>;
    using CalendarDatePicker = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::CalendarDatePicker>;
    using CalendarDatePickerDateChangedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::CalendarDatePickerDateChangedEventArgs>;
    using CalendarView = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::CalendarView>;
    using CalendarViewDayItem = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::CalendarViewDayItem>;
    using CalendarViewDayItemChangingEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::CalendarViewDayItemChangingEventArgs>;
    using CalendarViewSelectedDatesChangedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::CalendarViewSelectedDatesChangedEventArgs>;
    using CandidateWindowBoundsChangedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::CandidateWindowBoundsChangedEventArgs>;
    using Canvas = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::Canvas>;
    using CaptureElement = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::CaptureElement>;
    using CheckBox = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::CheckBox>;
    using ChoosingGroupHeaderContainerEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::ChoosingGroupHeaderContainerEventArgs>;
    using ChoosingItemContainerEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::ChoosingItemContainerEventArgs>;
    using CleanUpVirtualizedItemEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::CleanUpVirtualizedItemEventArgs>;
    using ColorChangedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::ColorChangedEventArgs>;
    using ColorPicker = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::ColorPicker>;
    using ColumnDefinition = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::ColumnDefinition>;
    using ColumnDefinitionCollection = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::ColumnDefinitionCollection>;
    using ComboBox = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::ComboBox>;
    using ComboBoxItem = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::ComboBoxItem>;
    using ComboBoxTextSubmittedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::ComboBoxTextSubmittedEventArgs>;
    using CommandBar = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::CommandBar>;
    using CommandBarFlyout = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::CommandBarFlyout>;
    using CommandBarOverflowPresenter = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::CommandBarOverflowPresenter>;
    using ContainerContentChangingEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::ContainerContentChangingEventArgs>;
    using ContentControl = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::ContentControl>;
    using ContentDialog = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::ContentDialog>;
    using ContentDialogButtonClickDeferral = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::ContentDialogButtonClickDeferral>;
    using ContentDialogButtonClickEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::ContentDialogButtonClickEventArgs>;
    using ContentDialogClosedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::ContentDialogClosedEventArgs>;
    using ContentDialogClosingDeferral = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::ContentDialogClosingDeferral>;
    using ContentDialogClosingEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::ContentDialogClosingEventArgs>;
    using ContentDialogOpenedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::ContentDialogOpenedEventArgs>;
    using ContentLinkChangedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::ContentLinkChangedEventArgs>;
    using ContentPresenter = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::ContentPresenter>;
    using ContextMenuEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::ContextMenuEventArgs>;
    using Control = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::Control>;
    using ControlTemplate = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::ControlTemplate>;
    using DataTemplateSelector = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::DataTemplateSelector>;
    using DatePickedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::DatePickedEventArgs>;
    using DatePicker = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::DatePicker>;
    using DatePickerFlyout = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::DatePickerFlyout>;
    using DatePickerFlyoutItem = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::DatePickerFlyoutItem>;
    using DatePickerFlyoutPresenter = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::DatePickerFlyoutPresenter>;
    using DatePickerSelectedValueChangedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::DatePickerSelectedValueChangedEventArgs>;
    using DatePickerValueChangedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::DatePickerValueChangedEventArgs>;
    using DragItemsCompletedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::DragItemsCompletedEventArgs>;
    using DragItemsStartingEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::DragItemsStartingEventArgs>;
    using DropDownButton = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::DropDownButton>;
    using DropDownButtonAutomationPeer = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::DropDownButtonAutomationPeer>;
    using DynamicOverflowItemsChangingEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::DynamicOverflowItemsChangingEventArgs>;
    using FlipView = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::FlipView>;
    using FlipViewItem = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::FlipViewItem>;
    using Flyout = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::Flyout>;
    using FlyoutPresenter = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::FlyoutPresenter>;
    using FocusDisengagedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::FocusDisengagedEventArgs>;
    using FocusEngagedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::FocusEngagedEventArgs>;
    using FontIcon = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::FontIcon>;
    using FontIconSource = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::FontIconSource>;
    using Frame = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::Frame>;
    using Grid = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::Grid>;
    using GridView = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::GridView>;
    using GridViewHeaderItem = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::GridViewHeaderItem>;
    using GridViewItem = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::GridViewItem>;
    using GroupItem = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::GroupItem>;
    using GroupStyle = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::GroupStyle>;
    using GroupStyleSelector = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::GroupStyleSelector>;
    using HandwritingPanelClosedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::HandwritingPanelClosedEventArgs>;
    using HandwritingPanelOpenedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::HandwritingPanelOpenedEventArgs>;
    using HandwritingView = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::HandwritingView>;
    using HandwritingViewCandidatesChangedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::HandwritingViewCandidatesChangedEventArgs>;
    using HandwritingViewTextSubmittedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::HandwritingViewTextSubmittedEventArgs>;
    using Hub = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::Hub>;
    using HubSection = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::HubSection>;
    using HubSectionCollection = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::HubSectionCollection>;
    using HubSectionHeaderClickEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::HubSectionHeaderClickEventArgs>;
    using HyperlinkButton = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::HyperlinkButton>;
    using IconElement = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::IconElement>;
    using IconSource = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::IconSource>;
    using IconSourceElement = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::IconSourceElement>;
    using Image = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::Image>;
    using InkCanvas = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::InkCanvas>;
    using InkToolbar = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::InkToolbar>;
    using InkToolbarBallpointPenButton = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::InkToolbarBallpointPenButton>;
    using InkToolbarCustomPen = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::InkToolbarCustomPen>;
    using InkToolbarCustomPenButton = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::InkToolbarCustomPenButton>;
    using InkToolbarCustomToggleButton = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::InkToolbarCustomToggleButton>;
    using InkToolbarCustomToolButton = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::InkToolbarCustomToolButton>;
    using InkToolbarEraserButton = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::InkToolbarEraserButton>;
    using InkToolbarFlyoutItem = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::InkToolbarFlyoutItem>;
    using InkToolbarHighlighterButton = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::InkToolbarHighlighterButton>;
    using InkToolbarIsStencilButtonCheckedChangedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::InkToolbarIsStencilButtonCheckedChangedEventArgs>;
    using InkToolbarMenuButton = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::InkToolbarMenuButton>;
    using InkToolbarPenButton = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::InkToolbarPenButton>;
    using InkToolbarPenConfigurationControl = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::InkToolbarPenConfigurationControl>;
    using InkToolbarPencilButton = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::InkToolbarPencilButton>;
    using InkToolbarRulerButton = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::InkToolbarRulerButton>;
    using InkToolbarStencilButton = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::InkToolbarStencilButton>;
    using InkToolbarToggleButton = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::InkToolbarToggleButton>;
    using InkToolbarToolButton = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::InkToolbarToolButton>;
    using IsTextTrimmedChangedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::IsTextTrimmedChangedEventArgs>;
    using ItemClickEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::ItemClickEventArgs>;
    using ItemCollection = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::ItemCollection>;
    using ItemContainerGenerator = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::ItemContainerGenerator>;
    using ItemsControl = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::ItemsControl>;
    using ItemsPanelTemplate = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::ItemsPanelTemplate>;
    using ItemsPickedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::ItemsPickedEventArgs>;
    using ItemsPresenter = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::ItemsPresenter>;
    using ItemsStackPanel = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::ItemsStackPanel>;
    using ItemsWrapGrid = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::ItemsWrapGrid>;
    using ListBox = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::ListBox>;
    using ListBoxItem = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::ListBoxItem>;
    using ListPickerFlyout = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::ListPickerFlyout>;
    using ListPickerFlyoutPresenter = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::ListPickerFlyoutPresenter>;
    using ListView = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::ListView>;
    using ListViewBase = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::ListViewBase>;
    using ListViewBaseHeaderItem = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::ListViewBaseHeaderItem>;
    using ListViewHeaderItem = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::ListViewHeaderItem>;
    using ListViewItem = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::ListViewItem>;
    using ListViewPersistenceHelper = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::ListViewPersistenceHelper>;
    using MediaElement = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::MediaElement>;
    using MediaPlayerElement = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::MediaPlayerElement>;
    using MediaPlayerPresenter = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::MediaPlayerPresenter>;
    using MediaTransportControls = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::MediaTransportControls>;
    using MediaTransportControlsHelper = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::MediaTransportControlsHelper>;
    using MenuBar = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::MenuBar>;
    using MenuBarItem = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::MenuBarItem>;
    using MenuBarItemFlyout = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::MenuBarItemFlyout>;
    using MenuFlyout = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::MenuFlyout>;
    using MenuFlyoutItem = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::MenuFlyoutItem>;
    using MenuFlyoutItemBase = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::MenuFlyoutItemBase>;
    using MenuFlyoutPresenter = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::MenuFlyoutPresenter>;
    using MenuFlyoutSeparator = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::MenuFlyoutSeparator>;
    using MenuFlyoutSubItem = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::MenuFlyoutSubItem>;
    using NavigationView = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::NavigationView>;
    using NavigationViewBackRequestedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::NavigationViewBackRequestedEventArgs>;
    using NavigationViewDisplayModeChangedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::NavigationViewDisplayModeChangedEventArgs>;
    using NavigationViewItem = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::NavigationViewItem>;
    using NavigationViewItemBase = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::NavigationViewItemBase>;
    using NavigationViewItemHeader = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::NavigationViewItemHeader>;
    using NavigationViewItemInvokedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::NavigationViewItemInvokedEventArgs>;
    using NavigationViewItemSeparator = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::NavigationViewItemSeparator>;
    using NavigationViewList = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::NavigationViewList>;
    using NavigationViewPaneClosingEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::NavigationViewPaneClosingEventArgs>;
    using NavigationViewSelectionChangedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::NavigationViewSelectionChangedEventArgs>;
    using NavigationViewTemplateSettings = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::NavigationViewTemplateSettings>;
    using NotifyEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::NotifyEventArgs>;
    using Page = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::Page>;
    using Panel = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::Panel>;
    using ParallaxView = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::ParallaxView>;
    using PasswordBox = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::PasswordBox>;
    using PasswordBoxPasswordChangingEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::PasswordBoxPasswordChangingEventArgs>;
    using PathIcon = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::PathIcon>;
    using PathIconSource = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::PathIconSource>;
    using PersonPicture = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::PersonPicture>;
    using PickerConfirmedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::PickerConfirmedEventArgs>;
    using PickerFlyout = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::PickerFlyout>;
    using PickerFlyoutPresenter = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::PickerFlyoutPresenter>;
    using Pivot = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::Pivot>;
    using PivotItem = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::PivotItem>;
    using PivotItemEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::PivotItemEventArgs>;
    using ProgressBar = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::ProgressBar>;
    using ProgressRing = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::ProgressRing>;
    using RadioButton = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::RadioButton>;
    using RatingControl = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::RatingControl>;
    using RatingItemFontInfo = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::RatingItemFontInfo>;
    using RatingItemImageInfo = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::RatingItemImageInfo>;
    using RatingItemInfo = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::RatingItemInfo>;
    using RefreshContainer = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::RefreshContainer>;
    using RefreshInteractionRatioChangedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::RefreshInteractionRatioChangedEventArgs>;
    using RefreshRequestedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::RefreshRequestedEventArgs>;
    using RefreshStateChangedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::RefreshStateChangedEventArgs>;
    using RefreshVisualizer = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::RefreshVisualizer>;
    using RelativePanel = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::RelativePanel>;
    using RichEditBox = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::RichEditBox>;
    using RichEditBoxSelectionChangingEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::RichEditBoxSelectionChangingEventArgs>;
    using RichEditBoxTextChangingEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::RichEditBoxTextChangingEventArgs>;
    using RichTextBlock = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::RichTextBlock>;
    using RichTextBlockOverflow = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::RichTextBlockOverflow>;
    using RowDefinition = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::RowDefinition>;
    using RowDefinitionCollection = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::RowDefinitionCollection>;
    using ScrollContentPresenter = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::ScrollContentPresenter>;
    using ScrollViewer = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::ScrollViewer>;
    using ScrollViewerView = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::ScrollViewerView>;
    using ScrollViewerViewChangedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::ScrollViewerViewChangedEventArgs>;
    using ScrollViewerViewChangingEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::ScrollViewerViewChangingEventArgs>;
    using SearchBox = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::SearchBox>;
    using SearchBoxQueryChangedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::SearchBoxQueryChangedEventArgs>;
    using SearchBoxQuerySubmittedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::SearchBoxQuerySubmittedEventArgs>;
    using SearchBoxResultSuggestionChosenEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::SearchBoxResultSuggestionChosenEventArgs>;
    using SearchBoxSuggestionsRequestedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::SearchBoxSuggestionsRequestedEventArgs>;
    using SectionsInViewChangedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::SectionsInViewChangedEventArgs>;
    using SelectionChangedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::SelectionChangedEventArgs>;
    using SemanticZoom = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::SemanticZoom>;
    using SemanticZoomLocation = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::SemanticZoomLocation>;
    using SemanticZoomViewChangedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::SemanticZoomViewChangedEventArgs>;
    using SettingsFlyout = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::SettingsFlyout>;
    using Slider = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::Slider>;
    using SplitButton = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::SplitButton>;
    using SplitButtonAutomationPeer = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::SplitButtonAutomationPeer>;
    using SplitButtonClickEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::SplitButtonClickEventArgs>;
    using SplitView = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::SplitView>;
    using SplitViewPaneClosingEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::SplitViewPaneClosingEventArgs>;
    using StackPanel = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::StackPanel>;
    using StyleSelector = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::StyleSelector>;
    using SwapChainBackgroundPanel = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::SwapChainBackgroundPanel>;
    using SwapChainPanel = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::SwapChainPanel>;
    using SwipeControl = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::SwipeControl>;
    using SwipeItem = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::SwipeItem>;
    using SwipeItemInvokedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::SwipeItemInvokedEventArgs>;
    using SwipeItems = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::SwipeItems>;
    using SymbolIcon = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::SymbolIcon>;
    using SymbolIconSource = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::SymbolIconSource>;
    using TextBlock = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::TextBlock>;
    using TextBox = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::TextBox>;
    using TextBoxBeforeTextChangingEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::TextBoxBeforeTextChangingEventArgs>;
    using TextBoxSelectionChangingEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::TextBoxSelectionChangingEventArgs>;
    using TextBoxTextChangingEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::TextBoxTextChangingEventArgs>;
    using TextChangedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::TextChangedEventArgs>;
    using TextCommandBarFlyout = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::TextCommandBarFlyout>;
    using TextCompositionChangedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::TextCompositionChangedEventArgs>;
    using TextCompositionEndedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::TextCompositionEndedEventArgs>;
    using TextCompositionStartedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::TextCompositionStartedEventArgs>;
    using TextControlCopyingToClipboardEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::TextControlCopyingToClipboardEventArgs>;
    using TextControlCuttingToClipboardEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::TextControlCuttingToClipboardEventArgs>;
    using TextControlPasteEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::TextControlPasteEventArgs>;
    using TimePickedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::TimePickedEventArgs>;
    using TimePicker = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::TimePicker>;
    using TimePickerFlyout = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::TimePickerFlyout>;
    using TimePickerFlyoutPresenter = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::TimePickerFlyoutPresenter>;
    using TimePickerSelectedValueChangedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::TimePickerSelectedValueChangedEventArgs>;
    using TimePickerValueChangedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::TimePickerValueChangedEventArgs>;
    using ToggleMenuFlyoutItem = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::ToggleMenuFlyoutItem>;
    using ToggleSplitButton = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::ToggleSplitButton>;
    using ToggleSplitButtonAutomationPeer = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::ToggleSplitButtonAutomationPeer>;
    using ToggleSplitButtonIsCheckedChangedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::ToggleSplitButtonIsCheckedChangedEventArgs>;
    using ToggleSwitch = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::ToggleSwitch>;
    using ToolTip = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::ToolTip>;
    using ToolTipService = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::ToolTipService>;
    using TreeView = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::TreeView>;
    using TreeViewCollapsedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::TreeViewCollapsedEventArgs>;
    using TreeViewDragItemsCompletedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::TreeViewDragItemsCompletedEventArgs>;
    using TreeViewDragItemsStartingEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::TreeViewDragItemsStartingEventArgs>;
    using TreeViewExpandingEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::TreeViewExpandingEventArgs>;
    using TreeViewItem = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::TreeViewItem>;
    using TreeViewItemInvokedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::TreeViewItemInvokedEventArgs>;
    using TreeViewItemTemplateSettings = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::TreeViewItemTemplateSettings>;
    using TreeViewList = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::TreeViewList>;
    using TreeViewNode = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::TreeViewNode>;
    using TwoPaneView = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::TwoPaneView>;
    using UIElementCollection = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::UIElementCollection>;
    using UserControl = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::UserControl>;
    using VariableSizedWrapGrid = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::VariableSizedWrapGrid>;
    using Viewbox = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::Viewbox>;
    using VirtualizingPanel = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::VirtualizingPanel>;
    using VirtualizingStackPanel = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::VirtualizingStackPanel>;
    using WebView = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::WebView>;
    using WebViewBrush = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::WebViewBrush>;
    using WebViewContentLoadingEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::WebViewContentLoadingEventArgs>;
    using WebViewDOMContentLoadedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::WebViewDOMContentLoadedEventArgs>;
    using WebViewDeferredPermissionRequest = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::WebViewDeferredPermissionRequest>;
    using WebViewLongRunningScriptDetectedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::WebViewLongRunningScriptDetectedEventArgs>;
    using WebViewNavigationCompletedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::WebViewNavigationCompletedEventArgs>;
    using WebViewNavigationFailedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::WebViewNavigationFailedEventArgs>;
    using WebViewNavigationStartingEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::WebViewNavigationStartingEventArgs>;
    using WebViewNewWindowRequestedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::WebViewNewWindowRequestedEventArgs>;
    using WebViewPermissionRequest = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::WebViewPermissionRequest>;
    using WebViewPermissionRequestedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::WebViewPermissionRequestedEventArgs>;
    using WebViewSeparateProcessLostEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::WebViewSeparateProcessLostEventArgs>;
    using WebViewSettings = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::WebViewSettings>;
    using WebViewUnsupportedUriSchemeIdentifiedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::WebViewUnsupportedUriSchemeIdentifiedEventArgs>;
    using WebViewUnviewableContentIdentifiedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::WebViewUnviewableContentIdentifiedEventArgs>;
    using WebViewWebResourceRequestedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::WebViewWebResourceRequestedEventArgs>;
    using WrapGrid = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::WrapGrid>;
    using ICommandBarElement = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::ICommandBarElement>;
    using ICommandBarElement2 = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::ICommandBarElement2>;
    using IInsertionPanel = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::IInsertionPanel>;
    using IItemContainerMapping = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::IItemContainerMapping>;
    using INavigate = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::INavigate>;
    using IScrollAnchorProvider = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::IScrollAnchorProvider>;
    using ISemanticZoomInformation = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::ISemanticZoomInformation>;
}

namespace py
{
    template <>
    struct delegate_python_type<winrt::Windows::UI::Xaml::Controls::BackClickEventHandler>
    {
        using type = py::impl::Windows::UI::Xaml::Controls::BackClickEventHandler;
    };

    template <>
    struct delegate_python_type<winrt::Windows::UI::Xaml::Controls::CalendarViewDayItemChangingEventHandler>
    {
        using type = py::impl::Windows::UI::Xaml::Controls::CalendarViewDayItemChangingEventHandler;
    };

    template <>
    struct delegate_python_type<winrt::Windows::UI::Xaml::Controls::CleanUpVirtualizedItemEventHandler>
    {
        using type = py::impl::Windows::UI::Xaml::Controls::CleanUpVirtualizedItemEventHandler;
    };

    template <>
    struct delegate_python_type<winrt::Windows::UI::Xaml::Controls::ContextMenuOpeningEventHandler>
    {
        using type = py::impl::Windows::UI::Xaml::Controls::ContextMenuOpeningEventHandler;
    };

    template <>
    struct delegate_python_type<winrt::Windows::UI::Xaml::Controls::DragItemsStartingEventHandler>
    {
        using type = py::impl::Windows::UI::Xaml::Controls::DragItemsStartingEventHandler;
    };

    template <>
    struct delegate_python_type<winrt::Windows::UI::Xaml::Controls::HubSectionHeaderClickEventHandler>
    {
        using type = py::impl::Windows::UI::Xaml::Controls::HubSectionHeaderClickEventHandler;
    };

    template <>
    struct delegate_python_type<winrt::Windows::UI::Xaml::Controls::ItemClickEventHandler>
    {
        using type = py::impl::Windows::UI::Xaml::Controls::ItemClickEventHandler;
    };

    template <>
    struct delegate_python_type<winrt::Windows::UI::Xaml::Controls::ListViewItemToKeyHandler>
    {
        using type = py::impl::Windows::UI::Xaml::Controls::ListViewItemToKeyHandler;
    };

    template <>
    struct delegate_python_type<winrt::Windows::UI::Xaml::Controls::ListViewKeyToItemHandler>
    {
        using type = py::impl::Windows::UI::Xaml::Controls::ListViewKeyToItemHandler;
    };

    template <>
    struct delegate_python_type<winrt::Windows::UI::Xaml::Controls::NotifyEventHandler>
    {
        using type = py::impl::Windows::UI::Xaml::Controls::NotifyEventHandler;
    };

    template <>
    struct delegate_python_type<winrt::Windows::UI::Xaml::Controls::SectionsInViewChangedEventHandler>
    {
        using type = py::impl::Windows::UI::Xaml::Controls::SectionsInViewChangedEventHandler;
    };

    template <>
    struct delegate_python_type<winrt::Windows::UI::Xaml::Controls::SelectionChangedEventHandler>
    {
        using type = py::impl::Windows::UI::Xaml::Controls::SelectionChangedEventHandler;
    };

    template <>
    struct delegate_python_type<winrt::Windows::UI::Xaml::Controls::SemanticZoomViewChangedEventHandler>
    {
        using type = py::impl::Windows::UI::Xaml::Controls::SemanticZoomViewChangedEventHandler;
    };

    template <>
    struct delegate_python_type<winrt::Windows::UI::Xaml::Controls::TextChangedEventHandler>
    {
        using type = py::impl::Windows::UI::Xaml::Controls::TextChangedEventHandler;
    };

    template <>
    struct delegate_python_type<winrt::Windows::UI::Xaml::Controls::TextControlPasteEventHandler>
    {
        using type = py::impl::Windows::UI::Xaml::Controls::TextControlPasteEventHandler;
    };

    template <>
    struct delegate_python_type<winrt::Windows::UI::Xaml::Controls::WebViewNavigationFailedEventHandler>
    {
        using type = py::impl::Windows::UI::Xaml::Controls::WebViewNavigationFailedEventHandler;
    };

}
